@@ -4,8 +4,24 @@ use warnings;
 use strict;
 use Carp;
 use Class::Struct;
+use Scalar::Util qw(weaken);
+use vars qw($VERSION);
+$VERSION = '0.6';
 
-use version; our $VERSION = qv('0.4');
+BEGIN {
+    struct (
+	"Net::IPTrie::_Node" => {
+	    'up'        => '$',
+	    'left'      => '$',
+	    'right'     => '$',
+	    'address'   => '$',
+	    'iaddress'  => '$',
+	    'prefix'    => '$',
+	    'data'      => '$',
+	});
+}
+
+use base qw (Net::IPTrie::_Node);
 
 =head1 NAME
 
@@ -19,18 +35,6 @@ Net::IPTrie::Node
 
  See Net::IPTrie
 
-=cut
-
-struct (
-'up'        => '$',
-'left'      => '$',
-'right'     => '$',
-'address'   => '$',
-'iaddress'  => '$',
-'prefix'    => '$',
-'data'      => '$',
-);
-
 =head1 CLASS METHODS
 
 =head2 new - Constructor
@@ -48,8 +52,28 @@ struct (
   Examples:
     my $n = Net::IPTrie::Node->new(up=>$up, address=>"10.0.0.1")
 
-=head1 INSTANCE METHODS
+=cut
 
+sub new {
+    my $ret = shift->SUPER::new(@_);
+    if ( defined($ret->{'Net::IPTrie::_Node::up'}) ) {
+	weaken $ret->{'Net::IPTrie::_Node::up'};
+    }
+    return $ret;
+}
+
+sub up {
+    my $self = shift;
+    if (@_) {
+	$self->{'Net::IPTrie::_Node::up'} = shift;
+	if ( defined($self->{'Net::IPTrie::_Node::up'}) ) {
+	    weaken $self->{'Net::IPTrie::_Node::up'};
+	}
+    }
+    return $self->{'Net::IPTrie::_Node::up'};
+}
+
+=head1 INSTANCE METHODS
 =cut
 
 ############################################################################
@@ -105,7 +129,7 @@ sub delete {
 
 =head1 AUTHOR
 
-Carlos Vicente  C<< <<cvicente@cpan.org>> >>
+Carlos Vicente  <cvicente@cpan.org>
 
 =head1 SEE ALSO
 
@@ -113,7 +137,7 @@ Carlos Vicente  C<< <<cvicente@cpan.org>> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007-2010, Carlos Vicente C<<cvicente@cpan.org>>. All rights reserved.
+Copyright (c) 2007-2010, Carlos Vicente <cvicente@cpan.org>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
